@@ -167,11 +167,12 @@ DebuggerManager *KCrashBackend::constructDebuggerManager()
 #elif !defined(Q_OS_WIN)
     QString defaultDebuggerName = config.readEntry("Debugger", QStringLiteral("gdb"));
 #else
-    QString defaultDebuggerName = config.readEntry("Debugger", QStringLiteral("kdbgwin"));
+    QString defaultDebuggerName = config.readEntry("Debugger", QStringLiteral("cdb"));
 #endif
 
     Debugger firstKnownGoodDebugger, preferredDebugger;
     foreach (const Debugger & debugger, internalDebuggers) {
+        qCDebug(DRKONQI_LOG) << "Check debugger if" << debugger.name() << "is installed:" << debugger.isInstalled();
         if (!firstKnownGoodDebugger.isValid() && debugger.isInstalled()) {
             firstKnownGoodDebugger = debugger;
         }
@@ -235,5 +236,3 @@ void KCrashBackend::emergencySaveFunction(int signal)
     Q_UNUSED(signal);
     ::kill(s_pid, SIGKILL);
 }
-
-
